@@ -319,7 +319,7 @@ photos_application_launch_search (PhotosApplication *self, const gchar* const *t
   g_free (str);
 
   state = g_variant_new ("b", TRUE);
-  g_action_group_change_action_state (G_ACTION_GROUP (self), "search", state);
+  g_action_change_state (G_ACTION (priv->search_action), state);
 
   priv->activation_timestamp = timestamp;
   g_application_activate (G_APPLICATION (self));
@@ -777,6 +777,7 @@ photos_application_shutdown (GApplication *application)
 {
   PhotosApplication *self = PHOTOS_APPLICATION (application);
 
+  gegl_exit ();
   tracker_extract_priority_call_clear_rdf_types (self->priv->extract_priority,
                                                  NULL,
                                                  photos_application_tracker_clear_rdf_types,
@@ -844,12 +845,19 @@ photos_application_startup (GApplication *application)
           GomMiner *miner;
           const gchar *extension_name;
 
+          error = NULL;
           miner = gom_miner_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
                                                     G_DBUS_PROXY_FLAGS_NONE,
                                                     base_item_class->miner_name,
                                                     base_item_class->miner_object_path,
                                                     NULL,
-                                                    NULL);
+                                                    &error);
+          if (error != NULL)
+            {
+              g_warning ("Unable to create GomMiner proxy for %s: %s", base_item_class->miner_name, error->message);
+              g_error_free (error);
+              continue;
+            }
 
           extension_name = g_io_extension_get_name (extension);
           g_object_set_data_full (G_OBJECT (miner), "provider-type", g_strdup (extension_name), g_free);
