@@ -1,5 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
+ * Copyright © 2015 Alessandro Bono
  * Copyright © 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
@@ -28,10 +29,12 @@
 #include <glib.h>
 
 #include "photos-base-model.h"
+#include "photos-filterable.h"
 
 
 struct _PhotosBaseModelPrivate
 {
+  GMenu *model;
   PhotosBaseManager *mngr;
 };
 
@@ -42,7 +45,34 @@ enum
 };
 
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhotosBaseModel, photos_base_model, GTK_TYPE_LIST_STORE);
+G_DEFINE_TYPE_WITH_PRIVATE (PhotosBaseModel, photos_base_model, G_TYPE_OBJECT);
+
+
+static void
+photos_base_model_action_state_changed (PhotosBaseModel *self, const gchar *action_name, GVariant *value)
+{
+  const gchar *id;
+
+  id = g_variant_get_string (value, NULL);
+  photos_base_manager_set_active_object_by_id (self->priv->mngr, id);
+}
+
+
+static void
+photos_base_model_active_changed (PhotosBaseModel *self, GObject *active_object)
+{
+  PhotosBaseModelPrivate *priv = self->priv;
+  GApplication *app;
+  GVariant *state;
+  const gchar *action_id;
+  const gchar *id;
+
+  app = g_application_get_default ();
+  action_id = photos_base_manager_get_action_id (priv->mngr);
+  id = photos_filterable_get_id (PHOTOS_FILTERABLE (active_object));
+  state = g_variant_new ("s", id);
+  g_action_group_change_action_state (G_ACTION_GROUP (app), action_id, state);
+}
 
 
 static void
@@ -51,43 +81,40 @@ photos_base_model_refresh (PhotosBaseModel *self)
   PhotosBaseModelPrivate *priv = self->priv;
   GHashTable *objects;
   GHashTableIter hash_iter;
+  GMenu *section;
   GObject *object;
-  GtkTreeIter model_iter;
+  const gchar *action_id;
   const gchar *id;
   const gchar *title;
 
-  gtk_list_store_clear (GTK_LIST_STORE (self));
+  g_menu_remove_all (priv->model);
 
   title = photos_base_manager_get_title (priv->mngr);
-  if (title != NULL)
-    {
-      gtk_list_store_append (GTK_LIST_STORE (self), &model_iter);
-      gtk_list_store_set (GTK_LIST_STORE (self),
-                          &model_iter,
-                          PHOTOS_BASE_MODEL_ID, "heading",
-                          PHOTOS_BASE_MODEL_NAME, "",
-                          PHOTOS_BASE_MODEL_HEADING_TEXT, title,
-                          -1);
-    }
+  action_id = photos_base_manager_get_action_id (priv->mngr);
+
+  section = g_menu_new ();
+  g_menu_append_section (priv->model, title, G_MENU_MODEL (section));
 
   objects = photos_base_manager_get_objects (priv->mngr);
 
   g_hash_table_iter_init (&hash_iter, objects);
   while (g_hash_table_iter_next (&hash_iter, (gpointer *) &id, (gpointer *) &object))
     {
+      GMenuItem *menu_item;
+      GVariant *target_value;
       gchar *name;
 
-      gtk_list_store_append (GTK_LIST_STORE (self), &model_iter);
-
       g_object_get (object, "name", &name, NULL);
-      gtk_list_store_set (GTK_LIST_STORE (self),
-                          &model_iter,
-                          PHOTOS_BASE_MODEL_ID, id,
-                          PHOTOS_BASE_MODEL_NAME, name,
-                          PHOTOS_BASE_MODEL_HEADING_TEXT, "",
-                          -1);
+
+      menu_item = g_menu_item_new (name, NULL);
+      target_value = g_variant_new ("s", id);
+      g_menu_item_set_action_and_target_value (menu_item, action_id, target_value);
+      g_menu_append_item (section, menu_item);
+
       g_free (name);
     }
+
+  g_object_unref (section);
 }
 
 
@@ -96,9 +123,14 @@ photos_base_model_constructed (GObject *object)
 {
   PhotosBaseModel *self = PHOTOS_BASE_MODEL (object);
   PhotosBaseModelPrivate *priv = self->priv;
+  GApplication *app;
+  const gchar *action_id;
+  gchar *detailed_signal;
 
   G_OBJECT_CLASS (photos_base_model_parent_class)->constructed (object);
 
+  priv->model = g_menu_new ();
+
   g_signal_connect_object (priv->mngr,
                            "object-added",
                            G_CALLBACK (photos_base_model_refresh),
@@ -110,6 +142,22 @@ photos_base_model_constructed (GObject *object)
                            self,
                            G_CONNECT_SWAPPED);
 
+  app = g_application_get_default ();
+  action_id = photos_base_manager_get_action_id (priv->mngr);
+  detailed_signal = g_strconcat ("action-state-changed::", action_id, NULL);
+  g_signal_connect_object (app,
+                           detailed_signal,
+                           G_CALLBACK (photos_base_model_action_state_changed),
+                           self,
+                           G_CONNECT_SWAPPED);
+  g_free (detailed_signal);
+
+  g_signal_connect_object (priv->mngr,
+                           "active-changed",
+                           G_CALLBACK (photos_base_model_active_changed),
+                           self,
+                           G_CONNECT_SWAPPED);
+
   photos_base_model_refresh (self);
 }
 
@@ -118,8 +166,10 @@ static void
 photos_base_model_dispose (GObject *object)
 {
   PhotosBaseModel *self = PHOTOS_BASE_MODEL (object);
+  PhotosBaseModelPrivate *priv = self->priv;
 
-  g_clear_object (&self->priv->mngr);
+  g_clear_object (&priv->model);
+  g_clear_object (&priv->mngr);
 
   G_OBJECT_CLASS (photos_base_model_parent_class)->dispose (object);
 }
@@ -146,13 +196,7 @@ photos_base_model_set_property (GObject *object, guint prop_id, const GValue *va
 static void
 photos_base_model_init (PhotosBaseModel *self)
 {
-  GType columns[] = {G_TYPE_STRING,    /* ID */
-                     G_TYPE_STRING,    /* NAME */
-                     G_TYPE_STRING};   /* HEADING TEXT */
-
   self->priv = photos_base_model_get_instance_private (self);
-
-  gtk_list_store_set_column_types (GTK_LIST_STORE (self), sizeof (columns) / sizeof (columns[0]), columns);
 }
 
 
@@ -175,8 +219,15 @@ photos_base_model_class_init (PhotosBaseModelClass *class)
 }
 
 
-GtkListStore *
+PhotosBaseModel *
 photos_base_model_new (PhotosBaseManager *mngr)
 {
   return g_object_new (PHOTOS_TYPE_BASE_MODEL, "manager", mngr, NULL);
 }
+
+
+GMenu *
+photos_base_model_get_model (PhotosBaseModel *self)
+{
+  return self->priv->model;
+}
