@@ -35,22 +35,10 @@ G_BEGIN_DECLS
   (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
    PHOTOS_TYPE_SEARCH_PROVIDER, PhotosSearchProvider))
 
-#define PHOTOS_SEARCH_PROVIDER_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), \
-   PHOTOS_TYPE_SEARCH_PROVIDER, PhotosSearchProviderClass))
-
 #define PHOTOS_IS_SEARCH_PROVIDER(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
    PHOTOS_TYPE_SEARCH_PROVIDER))
 
-#define PHOTOS_IS_SEARCH_PROVIDER_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
-   PHOTOS_TYPE_SEARCH_PROVIDER))
-
-#define PHOTOS_SEARCH_PROVIDER_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-   PHOTOS_TYPE_SEARCH_PROVIDER, PhotosSearchProviderClass))
-
 #define PHOTOS_SEARCH_PROVIDER_PATH_SUFFIX "/SearchProvider"
 
 typedef struct _PhotosSearchProvider      PhotosSearchProvider;
