@@ -148,8 +148,11 @@ photos_search_type_manager_class_init (PhotosSearchTypeManagerClass *class)
 PhotosBaseManager *
 photos_search_type_manager_new (void)
 {
+  return g_object_new (PHOTOS_TYPE_SEARCH_TYPE_MANAGER,
+                       "action-id", "search-type",
   /* Translators: "Type" refers to a search filter. eg., All, Albums,
    * Favorites and Photos.
    */
-  return g_object_new (PHOTOS_TYPE_SEARCH_TYPE_MANAGER, "title", C_("Search Filter", "Type"), NULL);
+                       "title", C_("Search Filter", "Type"),
+                       NULL);
 }
