@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013, 2014 Red Hat, Inc.
+ * Copyright © 2013, 2014, 2015 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
 #include "photos-query-builder.h"
 #include "photos-search-context.h"
 #include "photos-tracker-collections-controller.h"
+#include "photos-utils.h"
 
 
 struct _PhotosTrackerCollectionsControllerPrivate
@@ -39,9 +40,15 @@ struct _PhotosTrackerCollectionsControllerPrivate
 };
 
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhotosTrackerCollectionsController,
-                            photos_tracker_collections_controller,
-                            PHOTOS_TYPE_TRACKER_CONTROLLER);
+G_DEFINE_TYPE_WITH_CODE (PhotosTrackerCollectionsController,
+                         photos_tracker_collections_controller,
+                         PHOTOS_TYPE_TRACKER_CONTROLLER,
+                         G_ADD_PRIVATE (PhotosTrackerCollectionsController)
+                         photos_utils_ensure_extension_points ();
+                         g_io_extension_point_implement (PHOTOS_TRACKER_CONTROLLER_EXTENSION_POINT_NAME,
+                                                         g_define_type_id,
+                                                         "collections",
+                                                         0));
 
 
 static void
