@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright © 2012, 2013, 2014, 2015 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,6 +54,7 @@ struct _PhotosTrackerControllerPrivate
   PhotosQuery *current_query;
   PhotosTrackerQueue *queue;
   PhotosWindowMode mode;
+  gboolean is_frozen;
   gboolean is_started;
   gboolean query_queued;
   gboolean querying;
@@ -84,7 +85,8 @@ G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (PhotosTrackerController, photos_tracker_con
 typedef enum
 {
   PHOTOS_TRACKER_REFRESH_FLAGS_NONE = 0,
-  PHOTOS_TRACKER_REFRESH_FLAGS_RESET_OFFSET = 1 << 0
+  PHOTOS_TRACKER_REFRESH_FLAGS_DONT_SET_QUERY_STATUS = 1 << 0,
+  PHOTOS_TRACKER_REFRESH_FLAGS_RESET_OFFSET = 1 << 1,
 } PhotosTrackerRefreshFlags;
 
 static void photos_tracker_controller_refresh_internal (PhotosTrackerController *self, gint flags);
@@ -206,7 +208,7 @@ photos_tracker_controller_perform_current_query (PhotosTrackerController *self)
 static void
 photos_tracker_controller_offset_changed (PhotosTrackerController *self)
 {
-  photos_tracker_controller_perform_current_query (self);
+  photos_tracker_controller_refresh_internal (self, PHOTOS_TRACKER_REFRESH_FLAGS_DONT_SET_QUERY_STATUS);
 }
 
 
@@ -242,6 +244,9 @@ photos_tracker_controller_refresh_internal (PhotosTrackerController *self, gint
 
   priv->is_started = TRUE;
 
+  if (priv->is_frozen)
+    return;
+
   if (flags & PHOTOS_TRACKER_REFRESH_FLAGS_RESET_OFFSET)
     photos_offset_controller_reset_offset (priv->offset_cntrlr);
 
@@ -253,7 +258,9 @@ photos_tracker_controller_refresh_internal (PhotosTrackerController *self, gint
       return;
     }
 
-  photos_tracker_controller_set_query_status (self, TRUE);
+  if (!(flags & PHOTOS_TRACKER_REFRESH_FLAGS_DONT_SET_QUERY_STATUS))
+    photos_tracker_controller_set_query_status (self, TRUE);
+
   photos_tracker_controller_perform_current_query (self);
 }
 
@@ -456,6 +463,13 @@ photos_tracker_controller_refresh_for_object (PhotosTrackerController *self)
 }
 
 
+void
+photos_tracker_controller_set_frozen (PhotosTrackerController *self, gboolean frozen)
+{
+  self->priv->is_frozen = frozen;
+}
+
+
 void
 photos_tracker_controller_start (PhotosTrackerController *self)
 {
