@@ -64,7 +64,7 @@ struct _PhotosTrackerFavoritesControllerClass
 
 GType                     photos_tracker_favorites_controller_get_type          (void) G_GNUC_CONST;
 
-PhotosTrackerController  *photos_tracker_favorites_controller_new               (void);
+PhotosTrackerController  *photos_tracker_favorites_controller_dup_singleton     (void);
 
 G_END_DECLS
 
